/*
 * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_et extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AUD", "AU$" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EEK", "kr" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "JPY", "\u00a5" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MRU", "MRU" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "\u0e3f" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "USD", "$" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "adp", "Andorra peseeta" },
            { "aed", "Araabia \u00dchendemiraatide dirhem" },
            { "afa", "Afganistani afgaani (1927\u20132002)" },
            { "afn", "Afganistani afgaani" },
            { "alk", "Albaania lekk (1946\u20131965)" },
            { "all", "Albaania lekk" },
            { "amd", "Armeenia dramm" },
            { "ang", "Hollandi Antillide kulden" },
            { "aoa", "Angola kvanza" },
            { "aok", "Angola kvanza (1977\u20131990)" },
            { "aon", "Angola kvanza (1990\u20132000)" },
            { "aor", "Angola reformitud kvanza, 1995\u20131999" },
            { "ara", "Argentina austral" },
            { "arm", "Argentina peeso (1881\u20131970)" },
            { "arp", "Argentina peeso (1983\u20131985)" },
            { "ars", "Argentina peeso" },
            { "ats", "Austria \u0161illing" },
            { "aud", "Austraalia dollar" },
            { "awg", "Aruba kulden" },
            { "azm", "Aserbaid\u017eaani manat (1993\u20132006)" },
            { "azn", "Aserbaid\u017eaani manat" },
            { "bad", "Bosnia ja Hertsegoviina dinaar (1992\u20131994)" },
            { "bam", "Bosnia ja Hertsegoviina konverteeritav mark" },
            { "ban", "Bosnia ja Hertsegoviina uus dinaar (1994\u20131997)" },
            { "bbd", "Barbadose dollar" },
            { "bdt", "Bangladeshi taka" },
            { "bec", "Belgia konverteeritav frank" },
            { "bef", "Belgia frank" },
            { "bel", "Belgia arveldusfrank" },
            { "bgl", "Bulgaaria p\u00fcsiv leev" },
            { "bgn", "Bulgaaria leev" },
            { "bgo", "Bulgaaria leev (1879\u20131952)" },
            { "bhd", "Bahreini dinaar" },
            { "bif", "Burundi frank" },
            { "bmd", "Bermuda dollar" },
            { "bnd", "Brunei dollar" },
            { "bob", "Boliivia boliviaano" },
            { "bol", "Boliivia boliviaano (1863\u20131963)" },
            { "bop", "Boliivia peeso" },
            { "brb", "Brasiilia uus kruseiro (1967\u20131986)" },
            { "brc", "Brasiilia krusado" },
            { "bre", "Brasiilia kruseiro (1990\u20131993)" },
            { "brl", "Brasiilia reaal" },
            { "brr", "Brasiilia kruseiro (1993\u20131994)" },
            { "brz", "Brasiilia kruseiro (1942\u20131967)" },
            { "bsd", "Bahama dollar" },
            { "btn", "Bhutani ngultrum" },
            { "buk", "Birma kjatt" },
            { "bwp", "Botswana pula" },
            { "byb", "Valgevene uus rubla (1994\u20131999)" },
            { "byn", "Valgevene rubla" },
            { "byr", "Valgevene rubla (2000\u20132016)" },
            { "bzd", "Belize\u2019i dollar" },
            { "cad", "Kanada dollar" },
            { "cdf", "Kongo frank" },
            { "chf", "\u0160veitsi frank" },
            { "cle", "T\u0161iili eskuudo" },
            { "clp", "T\u0161iili peeso" },
            { "cnh", "Hiina j\u00fcaan (v\u00e4lismaine turg)" },
            { "cny", "Hiina j\u00fcaan" },
            { "cop", "Colombia peeso" },
            { "crc", "Costa Rica koloon" },
            { "csd", "Serbia dinaar (2002\u20132006)" },
            { "cuc", "Kuuba konverteeritav peeso" },
            { "cup", "Kuuba peeso" },
            { "cve", "Cabo Verde eskuudo" },
            { "cyp", "K\u00fcprose nael" },
            { "czk", "T\u0161ehhi kroon" },
            { "ddm", "Ida-Saksa mark" },
            { "dem", "Saksa mark" },
            { "djf", "Djibouti frank" },
            { "dkk", "Taani kroon" },
            { "dop", "Dominikaani peeso" },
            { "dzd", "Al\u017eeeria dinaar" },
            { "ecs", "Ecuadori sukre" },
            { "eek", "Eesti kroon" },
            { "egp", "Egiptuse nael" },
            { "ern", "Eritrea nakfa" },
            { "esp", "Hispaania peseeta" },
            { "etb", "Etioopia birr" },
            { "eur", "euro" },
            { "fim", "Soome mark" },
            { "fjd", "Fid\u017ei dollar" },
            { "fkp", "Falklandi saarte nael" },
            { "frf", "Prantsuse frank" },
            { "gbp", "Suurbritannia naelsterling" },
            { "gel", "Gruusia lari" },
            { "ghc", "Ghana sedi (1979\u20132007)" },
            { "ghs", "Ghana sedi" },
            { "gip", "Gibraltari nael" },
            { "gmd", "Gambia dalasi" },
            { "gnf", "Guinea frank" },
            { "gns", "Guinea syli" },
            { "grd", "Kreeka drahm" },
            { "gtq", "Guatemala ketsaal" },
            { "gwe", "Portugali Guinea eskuudo" },
            { "gwp", "Guinea-Bissau peeso" },
            { "gyd", "Guyana dollar" },
            { "hkd", "Hongkongi dollar" },
            { "hnl", "Hondurase lempiira" },
            { "hrd", "Horvaatia dinaar" },
            { "hrk", "Horvaatia kuna" },
            { "htg", "Haiti gurd" },
            { "huf", "Ungari forint" },
            { "idr", "Indoneesia ruupia" },
            { "iep", "Iiri nael" },
            { "ilp", "Iisraeli nael" },
            { "ilr", "Iisraeli seekel (1980\u20131985)" },
            { "ils", "Iisraeli uus seekel" },
            { "inr", "India ruupia" },
            { "iqd", "Iraagi dinaar" },
            { "irr", "Iraani riaal" },
            { "isj", "Islandi kroon (1918\u20131981)" },
            { "isk", "Islandi kroon" },
            { "itl", "Itaalia liir" },
            { "jmd", "Jamaica dollar" },
            { "jod", "Jordaania dinaar" },
            { "jpy", "Jaapani jeen" },
            { "kes", "Keenia \u0161illing" },
            { "kgs", "K\u00f5rg\u00f5zstani somm" },
            { "khr", "Kambod\u017ea riaal" },
            { "kmf", "Komoori frank" },
            { "kpw", "P\u00f5hja-Korea vonn" },
            { "kro", "L\u00f5una-Korea vonn (1945\u20131953)" },
            { "krw", "L\u00f5una-Korea vonn" },
            { "kwd", "Kuveidi dinaar" },
            { "kyd", "Kaimanisaarte dollar" },
            { "kzt", "Kasahstani tenge" },
            { "lak", "Laose kiip" },
            { "lbp", "Liibanoni nael" },
            { "lkr", "Sri Lanka ruupia" },
            { "lrd", "Libeeria dollar" },
            { "lsl", "Lesotho loti" },
            { "ltl", "Leedu litt" },
            { "luc", "Luksemburgi konverteeritav frank" },
            { "luf", "Luksemburgi frank" },
            { "lvl", "L\u00e4ti latt" },
            { "lvr", "L\u00e4ti rubla" },
            { "lyd", "Liib\u00fca dinaar" },
            { "mad", "Maroko dirhem" },
            { "maf", "Maroko frank" },
            { "mcf", "Monaco frank" },
            { "mdl", "Moldova leu" },
            { "mga", "Madagaskari ariari" },
            { "mgf", "Madagaskari frank" },
            { "mkd", "Makedoonia dinaar" },
            { "mkn", "Makedoonia dinaar (1992\u20131993)" },
            { "mlf", "Mali frank" },
            { "mmk", "Myanmari kjatt" },
            { "mnt", "Mongoolia tugrik" },
            { "mop", "Macau pataaka" },
            { "mro", "Mauritaania ugia (1973\u20132017)" },
            { "mru", "Mauritaania ugia" },
            { "mtl", "Malta liir" },
            { "mtp", "Malta nael" },
            { "mur", "Mauritiuse ruupia" },
            { "mvp", "Maldiivi ruupia (1947\u20131981)" },
            { "mvr", "Maldiivi ruupia" },
            { "mwk", "Malawi kvat\u0161a" },
            { "mxn", "Mehhiko peeso" },
            { "mxp", "Mehhiko peeso (1861\u20131992)" },
            { "myr", "Malaisia ringgit" },
            { "mze", "Mosambiigi eskuudo" },
            { "mzm", "Mosambiigi metikal (1980\u20132006)" },
            { "mzn", "Mosambiigi metikal" },
            { "nad", "Namiibia dollar" },
            { "ngn", "Nigeeria naira" },
            { "nic", "Nicaragua kordoba (1988\u20131991)" },
            { "nio", "Nicaragua kordoba" },
            { "nlg", "Hollandi kulden" },
            { "nok", "Norra kroon" },
            { "npr", "Nepali ruupia" },
            { "nzd", "Uus-Meremaa dollar" },
            { "omr", "Omaani riaal" },
            { "pab", "Panama balboa" },
            { "pei", "Peruu inti" },
            { "pen", "Peruu soll" },
            { "pes", "Peruu soll (1863\u20131965)" },
            { "pgk", "Paapua Uus-Guinea kina" },
            { "php", "Filipiini peeso" },
            { "pkr", "Pakistani ruupia" },
            { "pln", "Poola zlott" },
            { "plz", "Poola zlott (1950\u20131995)" },
            { "pte", "Portugali eskuudo" },
            { "pyg", "Paraguay guaranii" },
            { "qar", "Katari riaal" },
            { "rhd", "Rodeesia dollar" },
            { "rol", "Rumeenia leu (1952\u20132006)" },
            { "ron", "Rumeenia leu" },
            { "rsd", "Serbia dinaar" },
            { "rub", "Venemaa rubla" },
            { "rur", "Venemaa rubla (1991\u20131998)" },
            { "rwf", "Rwanda frank" },
            { "sar", "Saudi Araabia riaal" },
            { "sbd", "Saalomoni Saarte dollar" },
            { "scr", "Sei\u0161elli ruupia" },
            { "sdd", "Sudaani dinaar (1992\u20132007)" },
            { "sdg", "Sudaani nael" },
            { "sdp", "Sudaani nael (1957\u20131998)" },
            { "sek", "Rootsi kroon" },
            { "sgd", "Singapuri dollar" },
            { "shp", "Saint Helena nael" },
            { "sit", "Sloveenia tolar" },
            { "skk", "Slovaki kroon" },
            { "sll", "Sierra Leone leoone" },
            { "sos", "Somaalia \u0161illing" },
            { "srd", "Suriname dollar" },
            { "srg", "Suriname kulden" },
            { "ssp", "L\u00f5una-Sudaani nael" },
            { "std", "S\u00e3o Tom\u00e9 ja Pr\u00edncipe dobra (1977\u20132017)" },
            { "stn", "S\u00e3o Tom\u00e9 ja Pr\u00edncipe dobra" },
            { "sur", "NSVL-i rubla" },
            { "svc", "El Salvadori koloon" },
            { "syp", "S\u00fc\u00fcria nael" },
            { "szl", "Svaasimaa lilangeni" },
            { "thb", "Tai baat" },
            { "tjr", "Tad\u017eikistani rubla" },
            { "tjs", "Tad\u017eikistani somoni" },
            { "tmm", "T\u00fcrkmenistani manat (1993\u20132009)" },
            { "tmt", "T\u00fcrkmenistani manat" },
            { "tnd", "Tuneesia dinaar" },
            { "top", "Tonga pa\u2019anga" },
            { "tpe", "Timori eskuudo" },
            { "trl", "T\u00fcrgi liir (1922\u20132005)" },
            { "try", "T\u00fcrgi liir" },
            { "ttd", "Trinidadi ja Tobago dollar" },
            { "twd", "uus Taiwani dollar" },
            { "tzs", "Tansaania \u0161illing" },
            { "uah", "Ukraina grivna" },
            { "uak", "Ukraina karbovanets" },
            { "ugs", "Uganda \u0161illing (1966\u20131987)" },
            { "ugx", "Uganda \u0161illing" },
            { "usd", "USA dollar" },
            { "usn", "USA j\u00e4rgmise p\u00e4eva dollar" },
            { "uss", "USA sama p\u00e4eva dollar" },
            { "uyp", "Uruguay peeso (1975\u20131993)" },
            { "uyu", "Uruguay peeso" },
            { "uzs", "Usbekistani somm" },
            { "veb", "Venezuela boliivar (1871\u20132008)" },
            { "vef", "Venezuela boliivar (2008\u20132018)" },
            { "ves", "Venezuela boliivar" },
            { "vnd", "Vietnami dong" },
            { "vnn", "Vietnami dong (1978\u20131985)" },
            { "vuv", "Vanuatu vatu" },
            { "wst", "Samoa taala" },
            { "xaf", "Kesk-Aafrika CFA frank" },
            { "xag", "h\u00f5be" },
            { "xau", "kuld" },
            { "xba", "EURCO" },
            { "xbb", "Euroopa raha\u00fchik" },
            { "xbc", "Euroopa rahaline arvestus\u00fchik (XBC)" },
            { "xbd", "Euroopa rahaline arvestus\u00fchik (XBD)" },
            { "xcd", "Ida-Kariibi dollar" },
            { "xdr", "Rahvusvahelise Valuutafondi arvestus\u00fchik" },
            { "xeu", "ek\u00fc\u00fc" },
            { "xfo", "Prantsuse kuldfrank" },
            { "xfu", "Prantsuse UIC-frank" },
            { "xof", "L\u00e4\u00e4ne-Aafrika CFA frank" },
            { "xpd", "pallaadium" },
            { "xpf", "CFP frank" },
            { "xpt", "plaatina" },
            { "xts", "v\u00e4\u00e4ringute testkood" },
            { "xxx", "m\u00e4\u00e4ramata raha\u00fchik" },
            { "ydd", "Jeemeni dinaar" },
            { "yer", "Jeemeni riaal" },
            { "yum", "Jugoslaavia uus dinaar (1994\u20132002)" },
            { "yun", "Jugoslaavia konverteeritav dinaar (1990\u20131992)" },
            { "zar", "L\u00f5una-Aafrika rand" },
            { "zmk", "Sambia kvat\u0161a (1968\u20132012)" },
            { "zmw", "Sambia kvat\u0161a" },
            { "zrz", "Sairi zaire" },
            { "zwd", "Zimbabwe dollar (1980\u20132008)" },
            { "zwl", "Zimbabwe dollar (2009)" },
            { "zwr", "Zimbabwe dollar (2008)" },
        };
        return data;
    }
}
